==> Biobase_2.4.1.zip: Biobase/doc/BiobaseDevelopment.R <==
###################################################
### chunk number 1: Biobase
###################################################
options(width=69)
library(Biobase)


###################################################
### chunk number 2: eSet-class
###################################################
getClass("eSet")


###################################################
### chunk number 3: eSet-validity
###################################################
getValidity(getClass("eSet"))


###################################################
### chunk number 4: ExpressionSet-initialize eval=FALSE
###################################################
## obj <- new("eSet", phenoData = new("AnnotatedDataFrame"), experimentData = new("MIAME"), annotation = character(), exprs = new("matrix")) 


###################################################
### chunk number 5: newAssayData eval=FALSE
###################################################
## assayDataNew("environment", elt)


###################################################
### chunk number 6: assayData-storageMode
###################################################
data(sample.ExpressionSet)
storageMode(sample.ExpressionSet)
tryCatch(assayData(sample.ExpressionSet)$exprs <- log(exprs(sample.ExpressionSet)),
         error=function(err) cat(conditionMessage(err)))
exprs(sample.ExpressionSet) <- log(exprs(sample.ExpressionSet))


###################################################
### chunk number 7: ExpressionSet-class
###################################################
getClass("ExpressionSet")
getValidity(getClass("ExpressionSet"))


###################################################
### chunk number 8: SwirlSet-class
###################################################
setClass("SwirlSet", contains="eSet")


###################################################
### chunk number 9: SwirlSet-initialize
###################################################
setMethod("initialize", "SwirlSet",
          function(.Object,
                   R = new("matrix"),
                   G = new("matrix"),
                   Rb = new("matrix"),
                   Gb = new("matrix"),
                   ...) {
            callNextMethod(.Object,
                           R=R, G=G, Rb=Rb, Gb=Gb,
                           ...)
        })


###################################################
### chunk number 10: SwirlSet-initialize-2
###################################################
setMethod("initialize", "SwirlSet",
          function(.Object,
                   assayData=assayDataNew(
                     R=R, G=G, Rb=Rb, Gb=Gb),
                   R = new("matrix"),
                   G = new("matrix"),
                   Rb = new("matrix"),
                   Gb = new("matrix"),
                   ...) {
            if (!missing(assayData) && 
                any(!missing(R), !missing(G), !missing(Rb), !missing(Gb))) {
                warning("using 'assayData'; ignoring 'R', 'G', 'Rb', 'Gb'")
            }
            callNextMethod(.Object, assayData=assayData, ...)
        })


###################################################
### chunk number 11: SwirlSet-new
###################################################
new("SwirlSet")


###################################################
### chunk number 12: initialize-.Object eval=FALSE
###################################################
## setMethod("initialize", "MySet",
##           function(.Object, ...) {
##               .Object <- callNextMethod(.Object, ...)
##           })
##               .


###################################################
### chunk number 13: SwirlSet-validity
###################################################
setValidity("SwirlSet", function(object) {
  assayDataValidMembers(assayData(object), c("R", "G", "Rb", "Gb"))
})


###################################################
### chunk number 14: validity-sometimes eval=FALSE
###################################################
## myFancyFunction <- function(obj) {
##   assayData(obj) <- fancyAssaydData # obj invalid...
##   phenoData(obj) <- justAsFancyPhenoData # but now valid
##   validObject(obj)
##   obj
## }


###################################################
### chunk number 15: updateObject-eg
###################################################
data(sample.ExpressionSet)
classVersion(sample.ExpressionSet)
obj <- updateObject(sample.ExpressionSet)


###################################################
### chunk number 16: isCurrent
###################################################
isCurrent(sample.ExpressionSet)[c("eSet", "ExpressionSet")]


###################################################
### chunk number 17: MultiSet-obj
###################################################
setClass("MySet",
         contains = "eSet",
         prototype = prototype(
           new("VersionedBiobase",
               versions=c(classVersion("eSet"), MySet="1.0.0"))))
obj <- new("MySet")
classVersion(obj)


###################################################
### chunk number 18: MultiSetRevised
###################################################
setClass("MySet",
         contains = "eSet",
         prototype = prototype(
           new("VersionedBiobase",
               versions=c(classVersion("eSet"), MySet="1.0.1"))))
isCurrent(obj)


###################################################
### chunk number 19: updateObject-MultiSet
###################################################
setMethod("updateObject", signature(object="MySet"),
          function(object, ..., verbose=FALSE) {
              if (verbose) message("updateObject(object = 'MySet')")
              object <- callNextMethod()
              if (isCurrent(object)["MySet"]) return(object)
              ## Create an updated instance.
              if (!isVersioned(object))
                  ## Radical surgery -- create a new, up-to-date instance
                  new("MySet",
                      assayData = updateObject(assayData(object),
                        ...., verbose=verbose),
                      phenoData = updateObject(phenoData(object),
                        ..., verbose=verbose),
                      experimentData = updateObject(experimentData(object),
                        ..., verbose=verbose),
                      annotation = updateObject(annotation(object),
                        ..., verbose=verbose))
              else {
                  ## Make minor changes, and update version by consulting class definition
                  classVersion(object)["MySet"] <-
                      classVersion("MySet")["MySet"]
                  object
              }
          })


###################################################
### chunk number 20: updateObject
###################################################
classVersion(updateObject(obj))


###################################################
### chunk number 21: classVersion-AnnotatedDataFrame
###################################################
classVersion(new("AnnotatedDataFrame"))


###################################################
### chunk number 22: SwirlSet-version
###################################################
setClass("SwirlSet", contains = "eSet",
         prototype = prototype(
           new("VersionedBiobase",
               versions=c(classVersion("eSet"), SwirlSet="1.0.0"))))
classVersion(new("SwirlSet"))


###################################################
### chunk number 23: arbitraryClassVersions
###################################################
obj <- new("SwirlSet")
classVersion(obj)["MyID"] <- "0.0.1"
classVersion(obj)
classVersion(updateObject(obj))


###################################################
### chunk number 24: 
###################################################
toLatex(sessionInfo())

==> Biobase_2.10.0.zip: Biobase/doc/BiobaseDevelopment.R <==
###################################################
### chunk number 1: Biobase
###################################################
#line 100 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp753tU5/R.INSTALL48d54977/Biobase/inst/doc/BiobaseDevelopment.Rnw"
options(width=69)
library(Biobase)


###################################################
### chunk number 2: eSet-class
###################################################
#line 111 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp753tU5/R.INSTALL48d54977/Biobase/inst/doc/BiobaseDevelopment.Rnw"
getClass("eSet")


###################################################
### chunk number 3: eSet-validity
###################################################
#line 234 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp753tU5/R.INSTALL48d54977/Biobase/inst/doc/BiobaseDevelopment.Rnw"
getValidity(getClass("eSet"))


###################################################
### chunk number 4: ExpressionSet-initialize eval=FALSE
###################################################
## #line 269 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp753tU5/R.INSTALL48d54977/Biobase/inst/doc/BiobaseDevelopment.Rnw"
## obj <- new("eSet", phenoData = new("AnnotatedDataFrame"), experimentData = new("MIAME"), annotation = character(), exprs = new("matrix")) 


###################################################
### chunk number 5: newAssayData eval=FALSE
###################################################
## #line 302 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp753tU5/R.INSTALL48d54977/Biobase/inst/doc/BiobaseDevelopment.Rnw"
## assayDataNew("environment", elt)


###################################################
### chunk number 6: assayData-storageMode
###################################################
#line 343 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp753tU5/R.INSTALL48d54977/Biobase/inst/doc/BiobaseDevelopment.Rnw"
data(sample.ExpressionSet)
storageMode(sample.ExpressionSet)
tryCatch(assayData(sample.ExpressionSet)$exprs <- log(exprs(sample.ExpressionSet)),
         error=function(err) cat(conditionMessage(err)))
exprs(sample.ExpressionSet) <- log(exprs(sample.ExpressionSet))


###################################################
### chunk number 7: ExpressionSet-class
###################################################
#line 375 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp753tU5/R.INSTALL48d54977/Biobase/inst/doc/BiobaseDevelopment.Rnw"
getClass("ExpressionSet")
getValidity(getClass("ExpressionSet"))


###################################################
### chunk number 8: SwirlSet-class
###################################################
#line 398 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp753tU5/R.INSTALL48d54977/Biobase/inst/doc/BiobaseDevelopment.Rnw"
setClass("SwirlSet", contains="eSet")


###################################################
### chunk number 9: SwirlSet-initialize
###################################################
#line 403 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp753tU5/R.INSTALL48d54977/Biobase/inst/doc/BiobaseDevelopment.Rnw"
setMethod("initialize", "SwirlSet",
          function(.Object,
                   R = new("matrix"),
                   G = new("matrix"),
                   Rb = new("matrix"),
                   Gb = new("matrix"),
                   ...) {
            callNextMethod(.Object,
                           R=R, G=G, Rb=Rb, Gb=Gb,
                           ...)
        })


###################################################
### chunk number 10: SwirlSet-initialize-2
###################################################
#line 422 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp753tU5/R.INSTALL48d54977/Biobase/inst/doc/BiobaseDevelopment.Rnw"
setMethod("initialize", "SwirlSet",
          function(.Object,
                   assayData=assayDataNew(
                     R=R, G=G, Rb=Rb, Gb=Gb),
                   R = new("matrix"),
                   G = new("matrix"),
                   Rb = new("matrix"),
                   Gb = new("matrix"),
                   ...) {
            if (!missing(assayData) && 
                any(!missing(R), !missing(G), !missing(Rb), !missing(Gb))) {
                warning("using 'assayData'; ignoring 'R', 'G', 'Rb', 'Gb'")
            }
            callNextMethod(.Object, assayData=assayData, ...)
        })


###################################################
### chunk number 11: SwirlSet-new
###################################################
#line 455 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp753tU5/R.INSTALL48d54977/Biobase/inst/doc/BiobaseDevelopment.Rnw"
new("SwirlSet")


###################################################
### chunk number 12: initialize-.Object eval=FALSE
###################################################
## #line 474 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp753tU5/R.INSTALL48d54977/Biobase/inst/doc/BiobaseDevelopment.Rnw"
## setMethod("initialize", "MySet",
##           function(.Object, ...) {
##               .Object <- callNextMethod(.Object, ...)
##           })
##               .


###################################################
### chunk number 13: SwirlSet-validity
###################################################
#line 493 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp753tU5/R.INSTALL48d54977/Biobase/inst/doc/BiobaseDevelopment.Rnw"
setValidity("SwirlSet", function(object) {
  assayDataValidMembers(assayData(object), c("R", "G", "Rb", "Gb"))
})


###################################################
### chunk number 14: validity-sometimes eval=FALSE
###################################################
## #line 506 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp753tU5/R.INSTALL48d54977/Biobase/inst/doc/BiobaseDevelopment.Rnw"
## myFancyFunction <- function(obj) {
##   assayData(obj) <- fancyAssaydData # obj invalid...
##   phenoData(obj) <- justAsFancyPhenoData # but now valid
##   validObject(obj)
##   obj
## }


###################################################
### chunk number 15: updateObject-eg
###################################################
#line 532 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp753tU5/R.INSTALL48d54977/Biobase/inst/doc/BiobaseDevelopment.Rnw"
data(sample.ExpressionSet)
classVersion(sample.ExpressionSet)
obj <- updateObject(sample.ExpressionSet)


###################################################
### chunk number 16: isCurrent
###################################################
#line 543 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp753tU5/R.INSTALL48d54977/Biobase/inst/doc/BiobaseDevelopment.Rnw"
isCurrent(sample.ExpressionSet)[c("eSet", "ExpressionSet")]


###################################################
### chunk number 17: MultiSet-obj
###################################################
#line 550 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp753tU5/R.INSTALL48d54977/Biobase/inst/doc/BiobaseDevelopment.Rnw"
setClass("MySet",
         contains = "eSet",
         prototype = prototype(
           new("VersionedBiobase",
               versions=c(classVersion("eSet"), MySet="1.0.0"))))
obj <- new("MySet")
classVersion(obj)


###################################################
### chunk number 18: MultiSetRevised
###################################################
#line 563 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp753tU5/R.INSTALL48d54977/Biobase/inst/doc/BiobaseDevelopment.Rnw"
setClass("MySet",
         contains = "eSet",
         prototype = prototype(
           new("VersionedBiobase",
               versions=c(classVersion("eSet"), MySet="1.0.1"))))
isCurrent(obj)


###################################################
### chunk number 19: updateObject-MultiSet
###################################################
#line 572 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp753tU5/R.INSTALL48d54977/Biobase/inst/doc/BiobaseDevelopment.Rnw"
setMethod("updateObject", signature(object="MySet"),
          function(object, ..., verbose=FALSE) {
              if (verbose) message("updateObject(object = 'MySet')")
              object <- callNextMethod()
              if (isCurrent(object)["MySet"]) return(object)
              ## Create an updated instance.
              if (!isVersioned(object))
                  ## Radical surgery -- create a new, up-to-date instance
                  new("MySet",
                      assayData = updateObject(assayData(object),
                        ...., verbose=verbose),
                      phenoData = updateObject(phenoData(object),
                        ..., verbose=verbose),
                      experimentData = updateObject(experimentData(object),
                        ..., verbose=verbose),
                      annotation = updateObject(annotation(object),
                        ..., verbose=verbose))
              else {
                  ## Make minor changes, and update version by consulting class definition
                  classVersion(object)["MySet"] <-
                      classVersion("MySet")["MySet"]
                  object
              }
          })


###################################################
### chunk number 20: updateObject
###################################################
#line 604 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp753tU5/R.INSTALL48d54977/Biobase/inst/doc/BiobaseDevelopment.Rnw"
classVersion(updateObject(obj))


###################################################
### chunk number 21: classVersion-AnnotatedDataFrame
###################################################
#line 620 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp753tU5/R.INSTALL48d54977/Biobase/inst/doc/BiobaseDevelopment.Rnw"
classVersion(new("AnnotatedDataFrame"))


###################################################
### chunk number 22: SwirlSet-version
###################################################
#line 638 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp753tU5/R.INSTALL48d54977/Biobase/inst/doc/BiobaseDevelopment.Rnw"
setClass("SwirlSet", contains = "eSet",
         prototype = prototype(
           new("VersionedBiobase",
               versions=c(classVersion("eSet"), SwirlSet="1.0.0"))))
classVersion(new("SwirlSet"))


###################################################
### chunk number 23: arbitraryClassVersions
###################################################
#line 649 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp753tU5/R.INSTALL48d54977/Biobase/inst/doc/BiobaseDevelopment.Rnw"
obj <- new("SwirlSet")
classVersion(obj)["MyID"] <- "0.0.1"
classVersion(obj)
classVersion(updateObject(obj))


###################################################
### chunk number 24: 
###################################################
#line 672 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp753tU5/R.INSTALL48d54977/Biobase/inst/doc/BiobaseDevelopment.Rnw"
toLatex(sessionInfo())
